@@ -66,18 +66,14 @@ impl<T> InlineVector<T> {
     pub fn push(&mut self, elem: T) {
         match self {
             &mut InlineVector::Inline(ref mut v) => {
-                let res = v.push(elem);
-                if res.is_some() {
-                    panic!("InlineVector capacity exceeded, please open a defect against \
-                            `basic_dsp`");
-                }
+                v.push(elem);
             }
         };
     }
 
     pub fn remove(&mut self, index: usize) -> T {
         match self {
-            &mut InlineVector::Inline(ref mut v) => v.remove(index).unwrap(),
+            &mut InlineVector::Inline(ref mut v) => v.remove(index),
         }
     }
 
@@ -118,7 +114,7 @@ impl<T> InlineVector<T> {
     pub fn insert(&mut self, index: usize, element: T) {
         match self {
             &mut InlineVector::Inline(ref mut v) => {
-                let _ = v.insert(index, element).unwrap();
+                let _ = v.insert(index, element);
             }
         }
     }
