@@ -499,9 +499,9 @@ impl<S, T, N, D> DspVec<S, T, N, D>
             Chunk::from_src_to_dest(complexity,
                                     &self.multicore_settings,
                                     &array[2 * scalar_left..2 * vectorization_length],
-                                    T::Reg::len(),
+                                    T::Reg::LEN,
                                     &mut temp[scalar_left..vectorization_length],
-                                    T::Reg::len() / 2,
+                                    T::Reg::LEN / 2,
                                     (),
                                     move |array, range, target, _arg| {
                 let mut i = 0;
@@ -509,7 +509,7 @@ impl<S, T, N, D> DspVec<S, T, N, D>
                 for n in array {
                     let result = op_simd(*n);
                     result.store_half_unchecked(target, i);
-                    i += T::Reg::len() / 2;
+                    i += T::Reg::LEN / 2;
                 }
             });
         }
