@@ -186,7 +186,7 @@ impl<S, T, N, D> DspVec<S, T, N, D>
         let mut temp = buffer.borrow(new_len);
         {
             let step = if self.is_complex() { 2 } else { 1 };
-            let number_of_shifts = T::Reg::len() / step;
+            let number_of_shifts = T::Reg::LEN / step;
             let vectors = function_to_vectors(function,
                                               conv_len,
                                               self.is_complex(),
@@ -223,7 +223,7 @@ impl<S, T, N, D> DspVec<S, T, N, D>
             let simd = T::Reg::array_to_regs(&data[scalar_left..vectorization_length]);
             // Length of a SIMD reg relative to the length of type T
             // which is 1 for real numbers or 2 for complex numbers
-            let simd_len_in_t = T::Reg::len() / step;
+            let simd_len_in_t = T::Reg::LEN / step;
             Chunk::execute_with_range(Complexity::Large,
                                       &self.multicore_settings,
                                       &mut dest[scalar_len..len - scalar_len],
